==> owncloud-4.0.4.tgz: owncloud/apps/contacts/l10n/zh_TW.php <==
<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "在啟用或關閉電話簿時發生錯誤",
"There was an error adding the contact." => "添加通訊錄發生錯誤",
"Cannot add empty property." => "不可添加空白內容",
"At least one of the address fields has to be filled out." => "至少必須填寫一欄地址",
"Error adding contact property." => "添加通訊錄內容中發生錯誤",
"No ID provided" => "未提供 ID",
"No contacts found." => "沒有找到聯絡人",
"Missing ID" => "遺失ID",
"Error adding addressbook." => "添加電話簿中發生錯誤",
"Error activating addressbook." => "啟用電話簿中發生錯誤",
"Information about vCard is incorrect. Please reload the page." => "有關 vCard 的資訊不正確，請重新載入此頁。",
"Error deleting contact property." => "刪除通訊錄內容中發生錯誤",
"Error updating contact property." => "更新通訊錄內容中發生錯誤",
"Error updating addressbook." => "電話簿更新中發生錯誤",
"No file was uploaded" => "沒有已上傳的檔案",
"Contacts" => "通訊錄",
"Addressbook not found." => "找不到通訊錄",
"This is not your addressbook." => "這不是你的電話簿",
"Contact could not be found." => "通訊錄未發現",
"Address" => "地址",
"Telephone" => "電話",
"Email" => "電子郵件",
"Organization" => "組織",
"Work" => "公司",
"Home" => "住宅",
"Mobile" => "行動電話",
"Text" => "文字",
"Voice" => "語音",
"Message" => "訊息",
"Fax" => "傳真",
"Video" => "影片",
"Pager" => "呼叫器",
"Internet" => "網際網路",
"{name}'s Birthday" => "{name}的生日",
"Contact" => "通訊錄",
"Add Contact" => "添加通訊錄",
"Addressbooks" => "電話簿",
"Configure Address Books" => "設定通訊錄",
"New Address Book" => "新電話簿",
"Import from VCF" => "從VCF匯入",
"CardDav Link" => "CardDav 聯結",
"Download" => "下載",
"Edit" => "編輯",
"Delete" => "刪除",
"Download contact" => "下載通訊錄",
"Delete contact" => "刪除通訊錄",
"Edit name details" => "編輯姓名詳細資訊",
"Nickname" => "綽號",
"Enter nickname" => "輸入綽號",
"Birthday" => "生日",
"dd-mm-yyyy" => "dd-mm-yyyy",
"Groups" => "群組",
"Separate groups with commas" => "用逗號分隔群組",
"Edit groups" => "編輯群組",
"Preferred" => "首選",
"Please specify a valid email address." => "註填入合法的電子郵件住址",
"Enter email address" => "輸入電子郵件地址",
"Mail to address" => "寄送住址",
"Delete email address" => "刪除電子郵件住址",
"Enter phone number" => "輸入電話號碼",
"Delete phone number" => "刪除電話號碼",
"Edit address details" => "電子郵件住址詳細資訊",
"Add notes here." => "在這裡新增註解",
"Add field" => "新增欄位",
"Profile picture" => "個人資料照片",
"Phone" => "電話",
"Note" => "註解",
"Type" => "類型",
"PO Box" => "通訊地址",
"Extended" => "分機",
"Street" => "街道",
"City" => "城市",
"Region" => "地區",
"Zipcode" => "郵遞區號",
"Country" => "國家",
"Add" => "添加",
"Addressbook" => "電話簿",
"Mr" => "先生",
"Sir" => "先生",
"Mrs" => "小姐",
"Dr" => "博士（醫生）",
"Given name" => "給定名（名）",
"Additional names" => "額外名",
"Family name" => "家族名（姓）",
"New Addressbook" => "新電話簿",
"Edit Addressbook" => "編輯電話簿",
"Displayname" => "顯示名稱",
"Active" => "作用中",
"Save" => "儲存",
"Submit" => "提出",
"Cancel" => "取消"
);

==> owncloud-4.5.7.tgz: owncloud/apps/contacts/l10n/zh_TW.php <==
<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "在啟用或關閉電話簿時發生錯誤",
"No ID provided" => "未提供 ID",
"No categories selected for deletion." => "未選取刪除的類別",
"No contacts found." => "沒有找到聯絡人",
"Cannot add empty property." => "不可添加空白內容",
"At least one of the address fields has to be filled out." => "至少必須填寫一欄地址",
"Information about vCard is incorrect. Please reload the page." => "有關 vCard 的資訊不正確，請重新載入此頁。",
"Missing ID" => "遺失ID",
"Information about vCard is incorrect. Please reload the page: " => "vCard資訊不正確. 請重新整理頁面:",
"File doesn't exist:" => "檔案不存在",
"No file was uploaded" => "沒有已上傳的檔案",
"Contacts" => "通訊錄",
"Download" => "下載",
"Edit" => "編輯",
"Delete" => "刪除",
"Cancel" => "取消",
"This is not your addressbook." => "這不是你的電話簿",
"Contact could not be found." => "通訊錄未發現",
"Work" => "公司",
"Home" => "住宅",
"Mobile" => "行動電話",
"Text" => "文字",
"Voice" => "語音",
"Message" => "訊息",
"Fax" => "傳真",
"Video" => "影片",
"Pager" => "呼叫器",
"Internet" => "網際網路",
"Birthday" => "生日",
"{name}'s Birthday" => "{name}的生日",
"Contact" => "通訊錄",
"Add Contact" => "添加通訊錄",
"Import" => "匯入",
"Upload new photo" => "上傳新照片",
"Edit name details" => "編輯姓名詳細資訊",
"Organization" => "組織",
"Nickname" => "綽號",
"Enter nickname" => "輸入綽號",
"dd-mm-yyyy" => "dd-mm-yyyy",
"Groups" => "群組",
"Separate groups with commas" => "用逗號分隔群組",
"Edit groups" => "編輯群組",
"Preferred" => "首選",
"Please specify a valid email address." => "註填入合法的電子郵件住址",
"Enter email address" => "輸入電子郵件地址",
"Mail to address" => "寄送住址",
"Delete email address" => "刪除電子郵件住址",
"Enter phone number" => "輸入電話號碼",
"Delete phone number" => "刪除電話號碼",
"Edit address details" => "電子郵件住址詳細資訊",
"Add notes here." => "在這裡新增註解",
"Add field" => "新增欄位",
"Phone" => "電話",
"Email" => "電子郵件",
"Address" => "地址",
"Note" => "註解",
"Download contact" => "下載通訊錄",
"Delete contact" => "刪除通訊錄",
"Edit address" => "編輯地址",
"Type" => "類型",
"PO Box" => "通訊地址",
"Extended" => "分機",
"City" => "城市",
"Region" => "地區",
"Zipcode" => "郵遞區號",
"Country" => "國家",
"Addressbook" => "電話簿",
"Mr" => "先生",
"Sir" => "先生",
"Mrs" => "小姐",
"Dr" => "博士（醫生）",
"Given name" => "給定名（名）",
"Additional names" => "額外名",
"Family name" => "家族名（姓）",
"Addressbooks" => "電話簿",
"New Address Book" => "新電話簿",
"Save" => "儲存"
);
